<?php

/**
 * Main class for making call to google weather service.
 */
class googleWeather {
  
  // Set up public variables so they can be accessed from outside.
  public $content, $location, $no_of_days, $error_message, $data;
  
  function __construct($location, $language) {
  	$this->error_message = t("Google weather information could not be requested.");
  	$this->location = $location;
  	$this->no_of_days = $location->days;
  	// Assigned to $this->data.
  	$this->weather_data($location, $language);
  	
  	return $this;
  }
  
	/**
	 * Main function to make call to google weather service using cURL lib.
	 */
	protected function weather_data(stdClass $location, $language) {
	
	  if ($location->days == NULL || !is_numeric($location->days)) {
	    $location->days = 1;
	  }
	
	  $timeout = variable_get("google_weather_timeout", 20);
	  $api = "http://www.google.com/ig/api?hl=" . $language->language . "&weather=";
	  $url = $api . urlencode($location->location);
	
	  $cv = @curl_version();
	  if (!is_array($cv)) {
	    watchdog('google_weather', 
	    	"Required cURL for download information about weather forecast from Google.", 
	    	array(), WATCHDOG_ERROR);
	    return $error_message;
	  }
	
	  $ch = @curl_init();
	  curl_setopt($ch, CURLOPT_URL, $url);
	  curl_setopt($ch, CURLOPT_HEADER, 0);
	  curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
	  curl_setopt($ch, CURLOPT_TIMEOUT, $timeout);
	
	  $data = @curl_exec($ch);
	  $encoding = array_pop(explode('charset=', curl_getinfo($ch, CURLINFO_CONTENT_TYPE)));
	  curl_close($ch);
		
		// another php plugin needed for this iconv to work??
	  if ($encoding != 'UTF-8') {
	  	$data = utf8_encode($data);
	  }
	
	  $xml = @simplexml_load_string($data);
	
	  if ($xml) {
	    if ($xml->weather->problem_cause) {
	      $blad = $xml->weather->problem_cause->attributes()->data;
	      return $blad;
	    }
	
	    $handler = $xml->weather;
	
	    $content = array();
	    $content['info'] = array(
	      'location' => (string) $handler->forecast_information->postal_code->attributes()->data,
	      'date' => (string) $handler->forecast_information->forecast_date->attributes()->data,
	    );

	    $today = &$handler->current_conditions;
	    $condition = (string) $today->condition->attributes()->data;
	    $convert_to = variable_get('google_weather_units', 'SI');
	    $unit = $this->weather_get_unit($convert_to);
	    $icon_src = (string)$today->icon->attributes()->data;

	    $image_vars = array(
	      'path' => 'http://www.google.com' . $icon_src,
	      'title' => $condition,
	      'alt' => $condition,
	    );

	    $content['current'] = array(
	      'temp' => (string) $this->weather_convert($today->temp_f->attributes()->data, $convert_to) . $unit,
	      'humidity' => (string) $today->humidity->attributes()->data,
	      'icon' => theme('image', $image_vars),
	      'condition' => $condition,
	      'wind_condition' => (string) $today->wind_condition->attributes()->data,
	    );
	
	    if (empty($icon_src)) {
	      $content['current']['icon'] = '<div class="spacer"></div>';
	    }
	
	    $i = 0;
	    $content['forecast'] = array();
	
	    foreach ($handler->forecast_conditions as $nextdays) {
	      $i++;
	      if ($i >= $location->days) continue;
	      $condition = (string) $nextdays->condition->attributes()->data;
	      $image_vars = array(
	      'path' => 'http://www.google.com' . (string) $nextdays->icon->attributes()->data,
	      'title' => $condition,
	      'alt' => $condition,
	      );
	      $content['forecast'][$i] = array(
	        'day' => ($i == 1) ? t("Today") : ucwords((string) $nextdays->day_of_week->attributes()->data),
	        'low_temp' => (string) $this->weather_convert($nextdays->low->attributes()->data, $convert_to) . $unit,
	        'high_temp' => (string) $this->weather_convert($nextdays->high->attributes()->data, $convert_to) . $unit,
	        'icon' => theme('image', $image_vars),
	        'condition' => $condition,
	      );
	    }
	
	    $content['forecast_header'] = t("Weather forecast");
	  }
	  else {
	    return t("Google weather service could not be requested");
	  }
	  
	  $this->data = $content;
	  return $content;
	}
	
	/**
	 * Helper function for convert units.
	 */
	protected function weather_convert($value, $convert_to) {
	  if (is_null($convert_to)) {
	    return $value;
	  } 
	  elseif ($convert_to == "SI") {
	    return round(($value-32)*5/9);
	  } 
	  else {
	  	// Already in Farenheit, so no need to convert.
	  	// (could be better, looks like nextdays is in Farenheit)
	    return $value; //return round($value*9/5+32);
	  }
	}
	
	/**
	 * Helper function to return global unit setting.
	 */
	protected function weather_get_unit($convert_to = NULL) {
	  if (is_null($convert_to)) {
	    $convert_to = variable_get('google_weather_units', 'SI');
	  }
	  if ($convert_to == "SI")
	    return '°C';
	  else
	    return '°F';
	}

	// Wrapper to return weather data.
	public function get_weather_data() {
		return $this->data;
	}

	// Pass the weather data through theme function.
	public function theme() {
		// Return message if no data present to pass to theme template.
		if (empty($this->data)) {
			return $data = t("Data could not be requested from google weather service.");
		}
		// Render data into template.
		else {
			drupal_add_css(drupal_get_path('module', 'google_weather') . '/google_weather.css');
  		return theme('google_weather_block', $this->data);
  	}
	}

} // Google weather class.
